@@ -1,6 +1,4 @@
-extern crate pkg_config;
-
 fn main() {
-    #[cfg(not(feature = "dlopen"))]
+    #[cfg(feature = "xkbcommon")]
     pkg_config::Config::new().find("xkbcommon").unwrap();
 }
